OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Adreces d'interès",
    "You bookmarked \"%s\"" : "Heu marcat \"%s\"",
    "%1$s bookmarked \"%2$s\"" : "%1$s ha marcat \"%2$s\"",
    "Someone bookmarked \"%s\"" : "Algú ha marcat \"%s\"",
    "You deleted \"%s\"" : "Heu suprimit \"%s\"",
    "%1$s deleted \"%2$s\"" : "%1$s ha suprimit \"%2$s\"",
    "Someone deleted \"%s\"" : "Algú ha suprimit \"%s\"",
    "You created folder \"%s\"" : "Heu creat la carpeta \"%s\"",
    "%1$s created folder \"%2$s\"" : "%1$s ha creat la carpeta \"%2$s\"",
    "Someone created folder \"%s\"" : "Algú ha creat la carpeta \"%s\"",
    "You moved folder \"%s\"" : "Heu mogut la carpeta \"%s\"",
    "%1$s moved folder \"%2$s\"" : "%1$s ha mogut la carpeta \"%2$s\"",
    "Someone moved folder \"%s\"" : "Algú ha mogut la carpeta \"%s\"",
    "You deleted folder \"%s\"" : "Heu suprimit la carpeta \"%s\"",
    "%1$s deleted folder \"%2$s\"" : "%1$s ha suprimit la carpeta \"%2$s\"",
    "Someone deleted folder \"%s\"" : "Algú ha suprimit la carpeta \"%s\"",
    "You shared folder \"%1$s\" with %2$s" : "Heu compartit la carpeta \"%1$s\" amb %2$s",
    "You shared folder \"%s\" with someone" : "Heu compartit la carpeta \"%s\" amb algú",
    "%1$s shared folder \"%2$s\" with you" : "%1$s ha compartit la carpeta \"%2$s\" amb tu",
    "Someone shared folder \"%s\" with you" : "Algú ha compartit la carpeta \"%s\" amb tu",
    "You unshared folder \"%1$s\" with %2$s" : "Heu deixat de compartit la carpeta \"%1$s\" amb %2$s",
    "You unshared folder \"%s\" with someone" : "Heu deixat de compartit la carpeta \"%s\" amb algú",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s ha deixat de compartir la carpeta \"%2$s\" amb vostè",
    "Someone unshared folder \"%s\" with you" : "Algú ha deixat de compartir la carpeta \"%s\" amb tu",
    "No file provided for import" : "No s'ha proporcionat cap fitxer per importar",
    "Unsupported file type for import" : "El tipus de fitxer que voleu importar no és compatible",
    "Bookmarks shared by %s" : "Adreces d'interès compartides per %s",
    "Recent Bookmarks" : "Adreces d'interès recents",
    "Bookmark" : "Marcadors",
    "Bookmark deleted" : "S'ha suprimit l'adreça d'interès",
    "Bookmark created" : "S’ha creat una adreça d’interès",
    "Bookmark moved" : "S' ha mogut l'adreça d'interès",
    "Bookmark updated" : "Adreça d'interès actualitzada",
    "Create bookmark" : "Crea una adreça d'interès",
    "Takes a link and adds it to your collection of bookmarks." : "Pren un enllaç i l'afegeix a la seva col·lecció d'adreces d'interès.",
    "A Bookmark manager for Nextcloud" : "Un gestor d'adreces d'interès per al Nextcloud",
    "Enter new title" : "Introduïu un títol nou",
    "Select bookmark" : "Seleccioneu una drecera d'interès",
    "Details" : "Detalls",
    "Rename" : "Canvia'n el nom",
    "Move" : "Mou",
    "Delete" : "Suprimeix",
    "Search" : "Cerca",
    "Select one or more tags" : "Seleccionau una o més etiquetes",
    "New" : "Nou",
    "New bookmark" : "Adreça d'interès nova",
    "New folder" : "Carpeta nova",
    "Grid view" : "Vista de graella",
    "List view" : "Vista de llista",
    "Move selection" : "Mou la selecció",
    "Delete selection" : "Suprimeix la selecció",
    "Open all selected" : "Obre tots els seleccionats",
    "Select all" : "Selecciona-ho tot",
    "Cancel selection" : "Cancel·la la selecció",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Carpetes {folders} seleccionades i adreces d'interès {bookmarks}",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["S'ha seleccionat %n adreça d'interès","S'han seleccionat %n adreces d'interès"],
    "_Selected %n folder_::_Selected %n folders_" : ["%n carpeta seleccionada","%n carpetes seleccionades"],
    "Enter a link" : "Introduïu un enllaç",
    "Enter a title" : "Escriviu el títol",
    "Select folder" : "Trieu una carpeta",
    "Enter folder title" : "Escriviu el títol de la carpeta",
    "Shared by {user}" : "Compartit per {user}",
    "Root folder" : "Carpeta d'arrel",
    "Submit" : "Envia",
    "Cancel" : "Cancel·la",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["S' està movent la carpeta %n i algunes adreces d'interès","S’ estan movent %n carpetes i algunes adreces d'interès"],
    "_Moving %n folder_::_Moving %n folders_" : ["S' està movent la carpeta %n","S’estan movent %n carpetes"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Movent %n preferit","Movent %n preferits"],
    "All bookmarks" : "Totes les adreces d'interès",
    "Recent" : "Recents",
    "Archived" : "Arxivat",
    "Broken links" : "Enllaços trencats",
    "Filter tags" : "Etiquetes de filtre",
    "Untagged" : "Sense etiqueta",
    "{used} bookmarks of {available} available" : "{used} marcadors de {available} disponibles",
    "No archived bookmarks" : "No hi ha adreces d'interès arxivades",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Les adreces d'interès a fitxers com ara fotos o PDF es desaran automàticament als fitxers Nextcloud, de manera que encara els podeu trobar fins i tot quan l'enllaç es desconnecti.",
    "No bookmarks here" : "No hi ha cap adreça d'interès",
    "Add a bookmark" : "Afegeix una adreça d'interès",
    "Import bookmarks" : "Importa adreces d'interès",
    "Import" : "Importa",
    "Export" : "Exporta",
    "Sorting" : "Ordenació",
    "Recently added" : "Afegides recentment",
    "Alphabetically" : "Alfabèticament",
    "Most visited" : "Les més visitades",
    "Last modified" : "Darrera modificació",
    "Custom order" : "Ordre personalitzat",
    "Archive path" : "Camí de l'arxiu",
    "Enter the path of a folder where bookmarked files should be stored" : "Introduïu el camí d'una carpeta on s'han d'emmagatzemar els fitxers marcats",
    "Client apps" : "Aplicacions de client",
    "Also check out the collection of client apps that integrate with this app: " : "Feu també un cop d'hora al conjunt d'aplicacions client que s'integren amb aquesta aplicació: ",
    "Bookmarklet" : "Miniaplicació d'adreces d'interès",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage" : "Arrossegueu-lo a les adreces d'interès del navegador i feu-hi clic per afegir ràpidament una pàgina web a les adreces d'interès",
    "Add to {instanceName}" : "Afegeix a {instanceName}",
    "Clear data" : "Neteja les dades",
    "Permanently remove all bookmarks from your account." : "Suprimeix permanentment totes les adreces d'interès del vostre compte.",
    "Delete all bookmarks" : "Suprimeix totes les adreces d'interès",
    "Do you really want to delete all your bookmarks?" : "Segur que voleu suprimir totes les adreces d'interès?",
    "Title" : "Títol",
    "Link" : "Enllaç",
    "Creation date" : "Data de creació",
    "Tags" : "Etiquetes",
    "Select tags and create new ones" : "Seleccioneu etiquetes i creeu-ne de noves",
    "Attachments" : "Adjunts",
    "Archived version" : "Versió arxivada",
    "Open archived file" : "Obre el fitxer arxivat",
    "Notes" : "Notes",
    "{time} ago" : "fa {time}",
    "Owner" : "Propietari",
    "Sharing" : "Compartició",
    "Select a user or group" : "Seleccioneu un usuari o un grup",
    "Share link" : "Enllaç de compartició",
    "Copy link" : "Copia l'enllaç",
    "Copy RSS feed" : "Copia canal RSS",
    "Delete link" : "Suprimeix l'enllaç",
    "Create public link" : "Crear un enllaç públic",
    "Allow editing" : "Permet l'edició",
    "Allow sharing" : "Permet compartir",
    "Remove share" : "Suprimeix la compartició",
    "Link copied" : "Enllaç copiat",
    "RSS feed copied" : "Canal RSS copiat",
    "Select" : "Selecciona",
    "Previews" : "Previsualitzacions",
    "In order to display real screenshots of your bookmarked websites, Bookmarks can use third-party services to generate previews." : "Per tal de mostrar captures de pantalla reals de les vostres adreces d’interès web, Adreces d'interès pot utilitzar serveis de tercers per generar visualitzacions prèvies.",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Podeu registrar-vos de forma gratuïta a screeenly.com configurar el vostre propi servidor.",
    "Screeenly API URL" : "URL de l'API de Screeenly",
    "Screeenly API key" : "Clau API de Screeenly",
    "Webshot" : "Foto web",
    "Webshot API URL" : "URL de l'API de webshot",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "Clau de l’API de ScreenshotMachine",
    "Pageres CLI" : "Pageres CLI",
    "Simply install the pageres cli on your server and bookmarks will find it." : "Simplement instal·leu els pageres cli al vostre servidor i els marcadors el trobaran.",
    "Privacy" : "Privadesa",
    "Bookmarks will try to access web pages that you add to automatically add information about them." : "Adreces d'interès intentarà accedir a les pàgines web que afegiu per afegir-ne informació automàticament.",
    "Enable accessing and collecting information from the web pages you add" : "Habiliteu l'accés i la recopilació d'informació de les pàgines web que afegiu",
    "Performance" : "Rendiment",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "En una instal·lació amb molts usuaris pot ser útil restringir el nombre d'adreces d'interès per compte.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Nombre màxim permès d'adreces d'interès per compte. (0 sense límit; per defecte no té límit)",
    "Failed to load settings" : "Ha fallat carregar la configuració",
    "Failed to save settings" : "Ha fallat desar la configuració",
    "This URL is already bookmarked! Overwrite?" : "Ja teniu aquest URL a les adreces d'interès. Voleu sobreescriure'l?",
    "Enter bookmark title" : "Escriviu el títol de l'adreça d'interès",
    "Enter bookmark URL" : "Introduïu l'adreça URL de les adreces d'interès",
    "Folder" : "Carpeta",
    "Root Folder" : "Carpeta arrel",
    "Save" : "Desa",
    "Failed to count unavailable bookmarks" : "No s'han pogut comptar les adreces d'interès no disponibles",
    "Failed to count archived bookmarks" : "No s'han pogut comptar les adreces d'interès arxivades",
    "Failed to load bookmark" : "No s'ha pogut carregar l'adreça d'interès",
    "Failed to find existing bookmark" : "Ha fallat trobar l'adreça d'interès existent",
    "Failed to create bookmark" : "Ha fallat crear l'adreça d'interès",
    "Failed to save bookmark" : "Ha fallat desar l'adreça d'interès",
    "Failed to move bookmark" : "Ha fallat moure l'adreça d'interès",
    "Failed to delete bookmark" : "Ha fallat suprimir l'adreça d'interès",
    "Failed to rename tag" : "No s'ha pogut canviar el nom de l'etiqueta",
    "Failed to load tags" : "Ha fallat carregar les etiquetes",
    "Failed to load folders" : "Ha fallat carregar les carpetes",
    "Failed to delete folder" : "Ha fallat suprimir la carpeta",
    "Failed to create folder" : "Ha fallat crear la carpeta",
    "Failed to fetch bookmarks." : "Ha fallat obtenir les adreces d'interès.",
    "Failed to change setting" : "Ha fallat canviar la configuració",
    "Failed to load setting {key}" : "No s'ha pogut carregar la configuració {key}",
    "Failed to update share {shareId}" : "No s'ha pogut actualitzar la compartició {shareId}",
    "Failed to delete share {shareId}" : "No s'ha pogut suprimir la compartició {shareId}",
    "Bookmarks feed" : "Canal d'adreces d'interès"
},
"nplurals=2; plural=(n != 1);");
